
package cluedo.info;


import java.io.Serializable;

/**
 * Base class for all information classes.  Instances of information
 * classes are used for communication between client and server.
 *
 * This class defines some constants for the game states.
 *
 * @author  PI4
 * @version $Id: Cluedoinfo.java,v 1.1.1.1 2001/05/14 07:47:15 gk Exp $d: Cluedoinfo.java,v 1.1.1.1 2001/04/24 11:00:12 gk Exp $
 * @see     cluedo.CluedoPDU
 */
public class CluedoInfo implements Serializable
{
    /** Used to indicate removed players, sessions etc. */
    public static final int REMOVED = -2;

    /** Used to indicate a currently unknown state of players, sessions etc. */
    public static final int UNKNOWN = -1;

    /** Server always has playerId = 0 */
    public static final int SERVERID= 0;

    /** Identifies players who are directors. @see Playerinfo.state */
    public static final int DIRECTOR= 0;

    /** Identifies players who are NOT directors. @see Playerinfo.state */
    public static final int TEAMMATE= 1;

    /** The maximum number of player in a session. */
    public static final int NUMPLAYERS= 6;

    /**
     * State of a newly created session. The game in this session has not
     * yet started, i.e. players can still join the session.
     * @see SessionInfo
     */
    public static final int OPENED    = 0;

    /**
     * State of a closed session. The game in this session has started, i.e.
     * players cannot join the session anymore.
     * @see SessionInfo
     */
    public static final int CLOSED    = 1;

    /**
     * State of a terminated session. The game in this session is finished,
     * i.e. players cannot join the session anymore.
     * @see SessionInfo
     */
    public static final int TERMINATED= 2;

    /**
     * Indicates that a player has been accepted. This means he is allowed
     * to join the session.
     *
     * @see PlayerNotifyInfo
     */
    public static final int ACCEPTED  = 0;

    /**
     * Indicates that a player has been rejected. This means he is not
     * allowed to join the session.
     *
     * @see PlayerNotifyInfo
     */
    public static final int REJECTED  = 1;

    /**
     * Indicates that a player has been expelled from a session. This means he does not
     * join the session anymore.
     *
     * @see PlayerNotifyInfo
     */
    public static final int EXPELLED  = 2;

    /**
     * Indicates that a player is invited for a session.
     *
     * @see PlayerNotifyInfo
     */
    public static final int INVITED  = 3;

    /**
     * Indicates that a player won the game.
     * @see WinnerInfo
     */
    public static final int WINNER = 0;

    /**
     * Indicates that a player lost the game.
     * @see WinnerInfo
     */
    public static final int LOOSER = 1;
}



