
package cluedo.info;



/**
 * An instance of this class describes a session.
 *
 * @author  PI4
 * @version $Id: Sessioninfo.java,v 1.1.1.1 2001/05/14 07:47:15 gk Exp $d: Sessioninfo.java,v 1.1.1.1 2001/04/24 11:00:12 gk Exp $
 * @see     cluedo.CluedoPDU
 */
public class SessionInfo extends CluedoInfo
{
    // Attribute

    /** id of the session */
    public int         sessionId;

    /** Name of the session */
    public String      sessionName;

    /**
     * "Pointer" to the player who has to carry out the next draw.  This
     * attribute is an index into the field {@link #teamMates teamMates}.
     */
    public int         activePlayerIndex;

    /** playerid of the director of this session. */
    public int         directorId;

    /** the players who participate in this session. */
    public int[]       teamMates;

    /**
     * state of the session.  A session can be OPENED, CLOSED or
     * TERMINATED.  The game of an open session has not yet begun and
     * other players can join the session.  The game of a closed session
     * has already begun and no other players can join.  The game of a
     * terminated session has already ended and the session waits to be
     * removed.
     */
    public int         state;

    /** All attributes are initialised to UNKNOWN or null. */
    public SessionInfo()
    {
	this.sessionId= UNKNOWN;
	this.sessionName= null;
	this.activePlayerIndex= UNKNOWN;
	this.directorId= UNKNOWN;
	this.teamMates= null;
	this.state= UNKNOWN;
    }

    /**
     * The directorid and the session name is set.  The teamMates field
     * is initialised and the director is the first team mate
     * (teammates[0]).
     */
    public SessionInfo(int directorId, String sessionName)
    {
	this.sessionId= UNKNOWN;
	this.sessionName= sessionName;
	this.activePlayerIndex= UNKNOWN;
	this.directorId= directorId;
	this.teamMates= new int[NUMPLAYERS];

	teamMates[0]= directorId;
	for (int i= 1; i < NUMPLAYERS; i++)
	    teamMates[i]= UNKNOWN;

	this.state= UNKNOWN;
    }
}
